Changelog
=========


(unreleased)
------------
- Release: version  🚀 [The Invoker]
- V0.0.35. [The Invoker]
- Bump v0.0.34. [The Invoker]
- Release: version  🚀 [The Invoker]
- Fix version. [The Invoker]
- Release: version  🚀 [The Invoker]
- Add invoke to configless commands. [The Invoker]
- Release: version  🚀 [The Invoker]
- Bump to v0.0.31. [The Invoker]
- Release: version  🚀 [The Invoker]
- Pump version to 0.0.30. [The Invoker]
- Release: version  🚀 [The Invoker]
- Bump 0.0.29. [The Invoker]
- Release: version  🚀 [The Invoker]
- Bump manifest to 0.0.28. [The Invoker]
- Release: version  🚀 [The Invoker]
- V0.0.27. [The Invoker]
- Release: version  🚀 [The Invoker]
- 0.0.26. [The Invoker]
- Release: version  🚀 [The Invoker]
- V0.0.25. [The Invoker]
- Release: version  🚀 [The Invoker]
- 0.0.240.0.240.0.240.0.240.0.240.0.240.0.240.0.240.0.24. [The Invoker]
- Change setup.py. [The Invoker]
- Release: version  🚀 [The Invoker]
- Change makefile. [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- New makefile. [The Invoker]
- Release: version  🚀 [The Invoker]
- Test makefile. [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- New makefile. [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Set v0.0.11. [The Invoker]
- Release: version  🚀 [The Invoker]
- Remove tests. [The Invoker]
- Release: version  🚀 [The Invoker]
- Release: version  🚀 [The Invoker]
- Remove linter. [The Invoker]
- Release: version  🚀 [The Invoker]
- Remove linter. [The Invoker]
- Release: version  🚀 [The Invoker]
- Fix lint errors. [The Invoker]
- Release: version  🚀 [The Invoker]
- Add initpy. [The Invoker]
- New manifest file. [The Invoker]
- Release: version  🚀 [The Invoker]
- Pump new version. [The Invoker]
- Add v0.0.1. [The Invoker]
- ✅ Ready to clone and code. [m00dy]
- Initial commit. [Eren Yagdiran]


